@@ -722,7 +722,21 @@ LEX* sp_lex_instr::parse_expr(THD *thd, sp_head *sp, LEX *sp_instr_lex)
     sp_instr_cursor_copy_struct) and in some cases for sp_instr_set.
   */
   if (sp_instr_lex == nullptr)
+  {
     thd->lex= new (thd->mem_root) st_lex_local;
+    lex_start(thd);
+    if (sp->m_handler->type() == SP_TYPE_TRIGGER)
+    {
+      /*
+        In case the trigger's statement being re-parsed, the correct trigger's
+        context (trigger event type and action time) should be copied from
+        trigger's sp_head to the new lex object.
+      */
+      thd->lex->trg_chistics.action_time=
+        thd->spcont->m_sp->m_trg->action_time;
+      thd->lex->trg_chistics.event= thd->spcont->m_sp->m_trg->event;
+    }
+  }
   else
   {
     sp_lex_cursor* cursor_lex= sp_instr_lex->get_lex_for_cursor();
@@ -742,8 +756,6 @@ LEX* sp_lex_instr::parse_expr(THD *thd, sp_head *sp, LEX *sp_instr_lex)
     DBUG_ASSERT(thd->lex == sp_instr_lex);
   }
 
-  lex_start(thd);
-
   thd->lex->sphead= sp;
   thd->lex->spcont= m_ctx;
 
@@ -1209,20 +1221,22 @@ bool sp_instr_set_trigger_field::on_after_expr_parsing(THD *thd)
 {
   DBUG_ASSERT(thd->lex->current_select->item_list.elements == 1);
 
-  value= thd->lex->current_select->item_list.head();
-  DBUG_ASSERT(value != nullptr);
+  Item *val= thd->lex->current_select->item_list.head();
+  DBUG_ASSERT(val != nullptr);
 
   trigger_field = new (thd->mem_root)
     Item_trigger_field(thd, thd->lex->current_context(),
                        Item_trigger_field::NEW_ROW,
                        m_trigger_field_name, UPDATE_ACL, false);
 
-  if (!value || !trigger_field)
+  if (!val || !trigger_field)
     return true;
 
   thd->spcont->m_sp->m_cur_instr_trig_field_items.link_in_list(
     trigger_field, &trigger_field->next_trg_field);
 
+  value= val;
+
   return false;
 }
 
